@@ -78,7 +78,7 @@ use Sys::Virt::NWFilter;
 use Sys::Virt::DomainSnapshot;
 use Sys::Virt::Stream;
 
-our $VERSION = '1.2.9';
+our $VERSION = '1.2.16';
 require XSLoader;
 XSLoader::load('Sys::Virt', $VERSION);
 
@@ -262,7 +262,7 @@ sub create_domain_with_files {
 				   fds => $fds, flags => $flags);
 }
 
-=item my $dom = $vmm->define_domain($xml);
+=item my $dom = $vmm->define_domain($xml, $flags=0);
 
 Defines, but does not start, a new domain based on the XML description
 passed into the C<$xml> parameter. The returned object is an instance
@@ -276,8 +276,9 @@ object.
 sub define_domain {
     my $self = shift;
     my $xml = shift;
+    my $flags = shift || 0;
 
-    return Sys::Virt::Domain->_new(connection => $self, xml => $xml, nocreate => 1);
+    return Sys::Virt::Domain->_new(connection => $self, xml => $xml, nocreate => 1, flags => $flags);
 }
 
 =item my $dom = $vmm->create_network($xml);
@@ -1605,6 +1606,10 @@ parameter can take one of
 Expand the CPU definition to list all feature flags, even those
 implied by the model name.
 
+=item Sys::Virt::BASELINE_CPU_MIGRATABLE
+
+Only include features which can be live migrated.
+
 =back
 
 =item @names = $con->get_cpu_model_names($arch, $flags=0)
@@ -1858,6 +1863,10 @@ How many pages changing too fast to be placed in a tree.
 
 How many milliseconds the shared memory service should sleep before next scan.
 
+=item Sys::Virt::NODE_MEMORY_SHARED_MERGE_ACROSS_NODES
+
+Whether pages can be merged across NUMA nodes
+
 =back
 
 =head2 CLOSE REASON CONSTANTS
