@@ -62,7 +62,7 @@ sub _new {
 	}
     } elsif (exists $params{xml}) {
 	if ($params{nocreate}) {
-	    $self = Sys::Virt::Domain::_define_xml($con,  $params{xml});
+	    $self = Sys::Virt::Domain::_define_xml($con,  $params{xml}, $params{flags});
 	} else {
 	    if (exists $params{fds}) {
 		$self = Sys::Virt::Domain::_create_with_files($con,  $params{xml},
@@ -356,6 +356,10 @@ The guest is paused while a snapshot takes place
 
 The guest is paused due to a kernel panic
 
+=item Sys::Virt::Domain::STATE_PAUSED_STARTING_UP
+
+The guest is paused as it is being started up.
+
 =item Sys::Virt::Domain::STATE_RUNNING_BOOTED
 
 The guest is running after being booted
@@ -473,11 +477,13 @@ the current state.
 
 =back
 
-=item my ($secs, $nsecs) = $dom->get_time($flags=0);
+=item my $time = $dom->get_time($flags=0);
 
 Get the current time of the guest, in seconds and nanoseconds.
 The C<$flags> parameter is currently unused and defaults to
-zero.
+zero. The return value is an array ref with two elements,
+the first contains the time in seconds, the second contains
+the remaining nanoseconds.
 
 =item $dom->set_time($secs, $nsecs, $flags=0);
 
@@ -492,6 +498,22 @@ Re-sync domain time from domain's RTC.
 
 =back
 
+
+=item $dom->set_user_password($username, $password, $flags=0);
+
+Update the password for account C<$username> to be
+C<$password>. C<$password> is the clear-text password
+string unless the PASSWORD_ENCRYPTED flag is set.
+
+=over 4
+
+=item C<Sys::Virt::Domain::PASSWORD_ENCRYPTED>
+
+The C<$password> is encrypted with the password scheme required
+by the guest OS.
+
+=back
+
 =item my @errs = $dom->get_disk_errors($flags=0)
 
 Returns a list of all disk errors that have occurred on
@@ -1214,6 +1236,35 @@ the physical CPUa, 8 cpus per character. To create a suitable
 bitstring, use the C<vec> function with a value of C<1> for the
 C<BITS> parameter.
 
+=item @iothreadinfo = $dom->get_iothread_info($flags=0)
+
+Obtain information about the state of all IOThreads in a running
+guest domain. The returned list will have one element for each IOThread,
+where each elements contains a hash reference. The keys in the hash
+are, C<number> the IOThread number and C<affinity> giving the allowed
+schedular placement. The value for C<affinity> is a
+string representing a bitmask against physical CPUs, 8 cpus per
+character. To extract the bits use the C<unpack> function with
+the C<b*> template.
+
+=item $dom->pin_iothread($iothread, $mask)
+
+Pin the IOThread given by index C<$iothread> to physical CPUs
+given by C<$mask>. The C<$mask> is a string representing a bitmask
+against physical CPUs, 8 cpus per character.
+
+=item $dom->add_iothread($iothread, $flags=0)
+
+Add a new IOThread by the C<$iothread> value to the guest domain.
+The C<$flags> parameter accepts one or more the CONFIG OPTION constants
+documented later, and defaults to 0 if omitted.
+
+=item $dom->del_iothread($iothread, $flags=0)
+
+Delete an existing IOThread by the C<$iothread> value from the guest domain.
+The C<$flags> parameter accepts one or more the CONFIG OPTION constants
+documented later, and defaults to 0 if omitted.
+
 =item my @stats = $dom->get_cpu_stats($startCpu, $numCpus, $flags=0)
 
 Requests the guests host physical CPU usage statistics, starting
@@ -1311,6 +1362,12 @@ Return the stats of the most recently completed job.
 
 The elapsed time in milliseconds
 
+=item Sys::Virt::Domain::JOB_TIME_ELAPSED_NET
+
+Time in miliseconds since the beginning of the migration job NOT
+including the time required to transfer control flow from the
+source host to the destination host.
+
 =item Sys::Virt::Domain::JOB_TIME_REMAINING
 
 The expected remaining time in milliseconds. Only set if the
@@ -1400,6 +1457,12 @@ non-compressed page.
 The number of milliseconds of downtime expected during
 migration switchover.
 
+=item Sys::Virt::Domain::JOB_DOWNTIME_NET
+
+Real measured downtime (ms) NOT including the time required to
+transfer control flow from the source host to the destination
+host.
+
 =item Sys::Virt::Domain::JOB_SETUP_TIME
 
 The number of milliseconds of time doing setup of the job
@@ -1626,6 +1689,90 @@ array reference. If <@mountPoints> is an empty list, then all
 filesystems will be thawed. C<$flags> is currently
 unused and defaults to zero.
 
+=item @fslist = $dom->get_fs_info($flags=0);
+
+Obtain a list of all guest filesystems. The returned list will
+contain one element for each filesystem, whose value will be
+a hash reference with the following keys
+
+=over 4
+
+=item name
+
+The name of the guest device that is mounted
+
+=item fstype
+
+The filesystem type (eg 'ext4', 'fat', 'ntfs', etc)
+
+=item mountpoint
+
+The location in the filesystem tree of the mount
+
+=item devalias
+
+An array reference containing list of device aliases
+associated with the guest device. The device aliases
+correspond to disk target names in the guest XML
+configuration
+
+=back
+
+=item @nics = $dom->get_interface_addresses($src, $flags=0);
+
+Obtain a list of all guest network interfaces. The C<$src>
+parameter is one of the constants
+
+=over 4
+
+=item Sys::Virt::Domain::INTERFACE_ADDRESSES_SRC_LEASE
+
+Extract the DHCP server lease information
+
+=item Sys::Virt::Domain::INTERFACE_ADDRESSES_SRC_AGENT
+
+Query the guest OS via an agent
+
+=back
+
+The returned list will contain one element for each interface.
+The values in the list will be a hash reference with the
+following keys
+
+=over 4
+
+=item name
+
+The name of the guest interface that is mounted
+
+=item hwaddr
+
+The hardware address, aka MAC, if available.
+
+=item addrs
+
+An array reference containing list of IP addresses
+associated with the guest NIC. Each element in the
+array is a further hash containing
+
+=over 4
+
+=item addr
+
+The IP address string
+
+=item prefix
+
+The IP address network prefix
+
+=item type
+
+The IP address type (IPv4 vs IPv6)
+
+=back
+
+=back
+
 =item $dom->send_process_signal($pid, $signum, $flags=0);
 
 Send the process C<$pid> the signal C<$signum>. The
@@ -1709,6 +1856,29 @@ The control channel is busy with a job
 
 =back
 
+If the status is C<Sys::Virt::Domain::CONTROL_ERROR>, then one
+of the following constants describes the reason
+
+=over 4
+
+=item Sys::Virt::Domain::CONTROL_ERROR_REASON_NONE
+
+There is no reason for the error available
+
+=item Sys::Virt::Domain::CONTROL_ERROR_REASON_UNKNOWN
+
+The reason for the error is unknown
+
+=item Sys::Virt::Domain::CONTROL_ERROR_REASON_INTERNAL
+
+There was an internal error in libvirt
+
+=item Sys::Virt::Domain::CONTROL_ERROR_REASON_MONITOR
+
+There was an error speaking to the monitor
+
+=back
+
 =head2 DOMAIN CREATION
 
 The following constants can be used to control the behaviour
@@ -1732,8 +1902,24 @@ Do not use OS I/O cache if starting a domain with a saved state image
 
 Boot the guest, even if there was a saved snapshot
 
+=item Sys::Virt::Domain::START_VALIDATE
+
+Validate the XML document against the XML schema
+
 =back
 
+=head2 DOMAIN DEFINE
+
+The following constants can be used to control the behaviour
+of domain define operations
+
+=over 4
+
+=item Sys::Virt::Domain::DEFINE_VALIDATE
+
+Validate the XML document against the XML schema
+
+=back
 
 =head2 KEYCODE SETS
 
@@ -2204,6 +2390,34 @@ The I/O operations read per second.
 
 The I/O operations written per second.
 
+=item Sys::Virt::Domain::BLOCK_IOTUNE_TOTAL_BYTES_SEC_MAX
+
+The maximum total bytes processed per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_READ_BYTES_SEC_MAX
+
+The maximum bytes read per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_WRITE_BYTES_SEC_MAX
+
+The maximum bytes written per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_TOTAL_IOPS_SEC_MAX
+
+The maximum total I/O operations processed per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_READ_IOPS_SEC_MAX
+
+The maximum I/O operations read per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_WRITE_IOPS_SEC_MAX
+
+The maximum I/O operations written per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_SIZE_IOPS_SEC
+
+The maximum I/O operations per second
+
 =back
 
 =head2 SCHEDULER CONSTANTS
@@ -2617,6 +2831,10 @@ Power management initiated wakeup
 
 Balloon target changes
 
+=item Sys::Virt::Domain::EVENT_ID_DEVICE_ADDED
+
+Asynchronous guest device addition
+
 =item Sys::Virt::Domain::EVENT_ID_DEVICE_REMOVED
 
 Asynchronous guest device removal
@@ -2628,6 +2846,42 @@ will be provided with a hash listing all changed parameters.
 The later DOMAIN TUNABLE constants can be useful when accessing
 the hash keys
 
+=item Sys::Virt::Domain::EVENT_ID_AGENT_LIFECYCLE
+
+Domain guest agent lifecycle events. The C<state> parameter
+to the callback will match one of the constants
+
+=over 4
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_STATE_CONNECTED
+
+The agent is now connected
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_STATE_DISCONNECTED
+
+The agent is now disconnected
+
+=back
+
+The second parameter, C<reason>, matches one of the following
+constants
+
+=over 4
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_REASON_UNKNOWN
+
+The reason is unknown
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_REASON_DOMAIN_STARTED
+
+The domain was initially booted
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_REASON_CHANNEL
+
+The channel on a running guest changed state
+
+=back
+
 =back
 
 =head2 IO ERROR EVENT CONSTANTS
@@ -3287,42 +3541,46 @@ bulk domain stats from C<Sys::Virt::get_all_domain_stats>.
 
 =over 4
 
-=item Sys::Virt::GET_ALL_STATS_ACTIVE
+=item Sys::Virt::Domain::GET_ALL_STATS_ACTIVE
 
 Include stats for active domains
 
-=item Sys::Virt::GET_ALL_STATS_INACTIVE
+=item Sys::Virt::Domain::GET_ALL_STATS_INACTIVE
 
 Include stats for inactive domains
 
-=item Sys::Virt::GET_ALL_STATS_OTHER
+=item Sys::Virt::Domain::GET_ALL_STATS_OTHER
 
 Include stats for other domains
 
-=item Sys::Virt::GET_ALL_STATS_PAUSED
+=item Sys::Virt::Domain::GET_ALL_STATS_PAUSED
 
 Include stats for paused domains
 
-=item Sys::Virt::GET_ALL_STATS_PERSISTENT
+=item Sys::Virt::Domain::GET_ALL_STATS_PERSISTENT
 
 Include stats for persistent domains
 
-=item Sys::Virt::GET_ALL_STATS_RUNNING
+=item Sys::Virt::Domain::GET_ALL_STATS_RUNNING
 
 Include stats for running domains
 
-=item Sys::Virt::GET_ALL_STATS_SHUTOFF
+=item Sys::Virt::Domain::GET_ALL_STATS_SHUTOFF
 
 Include stats for shutoff domains
 
-=item Sys::Virt::GET_ALL_STATS_TRANSIENT
+=item Sys::Virt::Domain::GET_ALL_STATS_TRANSIENT
 
 Include stats for transient domains
 
-=item Sys::Virt::GET_ALL_STATS_ENFORCE_STATS
+=item Sys::Virt::Domain::GET_ALL_STATS_ENFORCE_STATS
 
 Require that all requested stats fields are returned
 
+=item Sys::Virt::Domain::GET_ALL_STATS_BACKING
+
+Get stats for image backing files too
+
 =back
 
 =head2 DOMAIN STATS FIELD CONSTANTS
@@ -3691,6 +3949,38 @@ Write throughput in bytes per sec
 
 Write throughput in I/O operations per sec
 
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_READ_BYTES_SEC_MAX
+
+Maximum read throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_READ_IOPS_SEC_MAX
+
+Maximum read throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_TOTAL_BYTES_SEC_MAX
+
+Maximum total throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_TOTAL_IOPS_SEC_MAX
+
+Maximum total throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_WRITE_BYTES_SEC_MAX
+
+Maximum write throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_WRITE_IOPS_SEC_MAX
+
+Maximum write throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_SIZE_IOPS_SEC
+
+The maximum I/O operations per second
+
+=item Sys::Virt::Domain::TUNABLE_IOTHREADSPIN
+
+The I/O threads pinning
+
 =back
 
 =head1 AUTHORS
