@@ -362,6 +362,26 @@ The access control code
 
 The systemd init service
 
+=item Sys::Virt::Error::FROM_BHYVE
+
+The FreeBSD BHyve driver
+
+=item Sys::Virt::Error::FROM_CRYPTO
+
+The cryptographic helper APIs.
+
+=item Sys::Virt::Error::FROM_FIREWALL
+
+The firewall helper APIs.
+
+=item Sys::Virt::Error::FROM_POLKIT
+
+The polkit authentication / authorization APIs
+
+=item Sys::Virt::Error::FROM_THREAD
+
+The thread helper utils
+
 =back
 
 =head2 ERROR CODE CONSTANTS
@@ -736,6 +756,14 @@ An error from a DBus service API
 
 The storage volume already exists
 
+=item Sys::Virt::Error::ERR_CPU_INCOMPATIBLE
+
+The CPUs are not compatible
+
+=item Sys::Virt::Error::ERR_INVALID_SCHEMA
+
+The XML document does not comply with the XML schema
+
 =back
 
 =head1 AUTHORS
